==> pgmarket-1.4.4.tar.gz: pgmarket-1.4.4/admin/change_password.php <==
<?
/* change_password.php (c) 2000 Ying Zhang (ying@zippydesign.com)
 *
 * TERMS OF USAGE:
 * This file was written and developed by Ying Zhang (ying@zippydesign.com)
 * for educational and demonstration purposes only.  You are hereby granted the 
 * rights to use, modify, and redistribute this file as you like.  The only
 * requirement is that you must retain this notice, without modifications, at
 * the top of your source code.  No warranties or guarantees are expressed or
 * implied. DO NOT use this code in a production environment without
 * understanding the limitations and weaknesses pretaining to or caused by the
 * use of these scripts, directly or indirectly. USE AT YOUR OWN RISK!
 */

/* (c) 2000, 2001 Marco Pratesi <pratesi@telug.it> */

/******************************************************************************
 * MAIN
 *****************************************************************************/

include("../application.inc.php");
require_login();
require_priv("admin");

/* form has been submitted, check if it the user login information is correct */
if (match_referer() && isset($HTTP_POST_VARS)) {
	$frm = $HTTP_POST_VARS;
	$errormsg = validate_form($frm, $errors);

	if (empty($errormsg)) {
		update_user_password($frm["newpassword"], $frm["username"]);
		$noticemsg = $Password_Change_Successful;
	}
}

$DOC_TITLE = $Change_Password;
include("$CFG->templatedir"."header.ihtml");
include("$CFG->templatedir"."form_header.ihtml");
include("templates/change_password_form.ihtml");
include("$CFG->templatedir"."footer.ihtml");

/******************************************************************************
 * FUNCTIONS
 *****************************************************************************/

function validate_form(&$frm, &$errors) {

	global $CFG, $SESSION;
	include ($CFG->global);

	$errors = new Object;
	$msg = "";

	// md5("") = d41d8cd98f00b204e9800998ecf8427e
	if ($frm["oldpassword"] == "d41d8cd98f00b204e9800998ecf8427e") {
		$errors->oldpassword = true;
		$msg .= $no_old_password;

	} elseif (! password_valid($frm["oldpassword"], $frm["username"])) {
		$errors->oldpassword = true;
		$msg .= $old_password_not_valid;

	} elseif ($frm["newpassword"] == "d41d8cd98f00b204e9800998ecf8427e") {
		$errors->newpassword = true;
		$msg .= $no_new_password;

	} elseif ($frm["newpassword2"] == "d41d8cd98f00b204e9800998ecf8427e") {
		$errors->newpassword2 = true;
		$msg .= $no_new_password2;

	} elseif ($frm["newpassword"] != $frm["newpassword2"]) {
		$errors->newpassword = true;
		$errors->newpassword2 = true;
		$msg .= $new_passwords_dont_match;
	}

	return $msg;
}

function password_valid($password, $username) {
/* return true if the user's password is valid */

	global $SESSION;
	
	$qid = db_query("SELECT 1
			FROM users
			WHERE username = '$username' AND password = '$password'");
	return db_num_rows($qid);
}

function update_user_password($newpassword, $username) {
/* set the user's password to the new one */

	global $SESSION, $CFG;
	
	$qid = db_query("UPDATE users
			SET password = '$newpassword'
			WHERE username = '$username'");
	$qid = db_query("SELECT priv FROM users WHERE username = '$username'");
	$appoggio = db_fetch_array($qid, 0);

	if ($appoggio == "admin") {
		mail(
			"$CFG->seller_fullname <$CFG->seller_email>",
			"PgMarket root password changed",
			"PgMarket root password changed",
			"From: $CFG->support");
	}
}

?>

==> pgmarket-1.5.0.tar.gz: pgmarket-1.5.0/admin/change_password.php <==
<?
/* change_password.php (c) 2000 Ying Zhang (ying@zippydesign.com)
 *
 * TERMS OF USAGE:
 * This file was written and developed by Ying Zhang (ying@zippydesign.com)
 * for educational and demonstration purposes only.  You are hereby granted the 
 * rights to use, modify, and redistribute this file as you like.  The only
 * requirement is that you must retain this notice, without modifications, at
 * the top of your source code.  No warranties or guarantees are expressed or
 * implied. DO NOT use this code in a production environment without
 * understanding the limitations and weaknesses pretaining to or caused by the
 * use of these scripts, directly or indirectly. USE AT YOUR OWN RISK!
 */

/* (c) 2000, 2001 Marco Pratesi <pratesi@telug.it> */

/******************************************************************************
 * MAIN
 *****************************************************************************/

include("../application.inc.php");
require_login();
require_priv("admin");

/* form has been submitted, check if it the user login information is correct */
if (match_referer() && isset($HTTP_POST_VARS)) {
	$frm = $HTTP_POST_VARS;
	$errormsg = validate_form($frm, $errors);

	if (empty($errormsg)) {
		update_user_password($frm["newpassword"], $frm["username"]);
		$noticemsg = $Password_Change_Successful;
	}
}

$DOC_TITLE = "Change_Password";
include("$CFG->dirroot"."/header.php");
include("$CFG->dirroot"."/form_header.php");

$t = new Template();
$t->set_file(array("page" => "templates/change_password_form.ihtml"));
require($CFG->localedir . $SESSION["lang"] . "/global-common.inc.php");
$t->set_var("ME", $ME);
$t->set_var("md5dotjs", $CFG->libwww . "/md5.js");
$t->set_var(array(
		"username"		=> $username,
		"errors_oldpassword"    => errmsg($errors->oldpassword),
		"errors_newpassword"    => errmsg($errors->newpassword),
		"errors_newpassword2"   => errmsg($errors->newpassword2)
));
$t->pparse("out", "page");
//include("templates/change_password_form.ihtml");

include("$CFG->dirroot"."/footer.php");

/******************************************************************************
 * FUNCTIONS
 *****************************************************************************/

function validate_form(&$frm, &$errors) {

	global $CFG, $SESSION;
	include ($CFG->globalerror);

	$errors = new Object;
	$msg = "";

	// md5("") = d41d8cd98f00b204e9800998ecf8427e
	if ($frm["oldpassword"] == "d41d8cd98f00b204e9800998ecf8427e") {
		$errors->oldpassword = true;
		$msg .= $no_old_password;

	} elseif (! password_valid($frm["oldpassword"], $frm["username"])) {
		$errors->oldpassword = true;
		$msg .= $old_password_not_valid;

	} elseif ($frm["newpassword"] == "d41d8cd98f00b204e9800998ecf8427e") {
		$errors->newpassword = true;
		$msg .= $no_new_password;

	} elseif ($frm["newpassword2"] == "d41d8cd98f00b204e9800998ecf8427e") {
		$errors->newpassword2 = true;
		$msg .= $no_new_password2;

	} elseif ($frm["newpassword"] != $frm["newpassword2"]) {
		$errors->newpassword = true;
		$errors->newpassword2 = true;
		$msg .= $new_passwords_dont_match;
	}

	return $msg;
}

function password_valid($password, $username) {
/* return true if the user's password is valid */

	global $SESSION;
	
	$qid = db_query("SELECT 1
			FROM users
			WHERE username = '$username' AND password = '$password'");
	return db_num_rows($qid);
}

function update_user_password($newpassword, $username) {
/* set the user's password to the new one */

	global $SESSION, $CFG;
	
	$qid = db_query("UPDATE users
			SET password = '$newpassword'
			WHERE username = '$username'");

	if (has_priv("admin")) {
		mail(
			"$CFG->seller_fullname <$CFG->seller_email>",
			"PgMarket root password changed",
			"PgMarket root password changed",
			"From: $CFG->support");
	}
}

?>
